Welcome to django-rest-auth
===========================

.. image:: https://travis-ci.org/Tivix/django-rest-auth.png
    :target: https://travis-ci.org/Tivix/django-rest-auth


.. image:: https://coveralls.io/repos/Tivix/django-rest-auth/badge.png
    :target: https://coveralls.io/r/Tivix/django-rest-auth?branch=master


.. image:: https://readthedocs.org/projects/django-rest-auth/badge/?version=latest
    :target: https://readthedocs.org/projects/django-rest-auth/?badge=latest


Django-rest-auth provides a set of REST API endpoints for Authentication and Registration


Documentation
-------------
http://django-rest-auth.readthedocs.org/en/latest/


Source code
-----------
https://github.com/Tivix/django-rest-auth


Stack Overflow
-----------
http://stackoverflow.com/questions/tagged/django-rest-auth